#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from django.core.management.base import BaseCommand, CommandError
from arrogant.models import *
import requests, json, pyprind
from bs4 import BeautifulSoup

class Command(BaseCommand):
    help = 'Convenient Way to insert Intern of Yourator json into arrogant'
    def handle(self, *args, **options):
        self.getIntern()
        self.getJob()
        self.stdout.write(self.style.SUCCESS('crawl Job Json success!!!'))

    def getIntern(self):
        intern = []
        for i in range(1, 1000):
            if requests.get('https://www.yourator.co/api/v2/jobs?position[]=2&page={}'.format(i)).json()['jobs'] == []:
                break
            intern += requests.get('https://www.yourator.co/api/v2/jobs?position[]=2&page={}'.format(i)).json()['jobs']
        for i in pyprind.prog_bar(intern):
            # print(i)  
            res = requests.get('https://www.yourator.co/'+i['path']).text
            soup = BeautifulSoup(res, "html.parser")
            i['inside'] = {}
            i['inside']['description'] = soup.select('.description')[0].text.strip()
            for j in soup.select('.basic-info'):
                key, value = j.text.strip().replace(' ','').replace('\n','').split('：')
                i['inside'][key] = value

            if i['has_salary_info']:
                for j in soup.select('h2'):
                    if j.text == '薪資範圍':
                        i['salary'] = j.findNext('article').text
        with open('intern.json', 'w') as f:
            json.dump(self.testData(intern), f)

    def getJob(self):
        job = []
        for i in range(1, 1000):
            if requests.get('https://www.yourator.co/api/v2/jobs?page={}'.format(i)).json()['jobs'] == []:
                break
            job += requests.get('https://www.yourator.co/api/v2/jobs?page={}'.format(i)).json()['jobs']

        for i in pyprind.prog_bar(job):
            res = requests.get('https://www.yourator.co/'+i['path']).text
            soup = BeautifulSoup(res, "html.parser")
            i['inside'] = {}
            i['inside']['description'] = soup.select('.description')[0].text.strip() if len(soup.select('.description')) else ''
            for j in soup.select('.basic-info'):
                key, value = j.text.strip().replace(' ','').replace('\n','').split('：')
                i['inside'][key] = value

            if i['has_salary_info']:
                for j in soup.select('h2'):
                    if j.text == '薪資範圍':
                        i['salary'] = j.findNext('article').text
        with open('job.json', 'w') as f:
            json.dump(self.testData(job), f)

    @staticmethod
    def testData(data):
        return list(filter(lambda x:x['inside']['description']!='', data))


from django.core.management import call_command
from django.core.management.base import BaseCommand, CommandError
import time
class Command(BaseCommand):
    help = 'Convenient Way to insert Intern of Yourator json into arrogant'
    def handle(self, *args, **options):
        while True:
            call_command('jobCrawler')
            call_command('updateIntern', 'intern.json')
            call_command('updateIntern', 'job.json')
            time.sleep(86400)
        self.stdout.write(self.style.SUCCESS('daily update Intern and Job Info success!!!'))


# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-07 03:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('arrogant', '0002_job_available'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='name',
            field=models.CharField(default='', max_length=40),
        ),
    ]



from django.core.management.base import BaseCommand, CommandError
from arrogant.models import *
import json, pyprind

class Command(BaseCommand):
    help = 'Convenient Way to insert Intern of Yourator json into arrogant'
    def add_arguments(self, parser):
            # Positional arguments
            parser.add_argument('json', type=str)

    def handle(self, *args, **options):
        Job.objects.all().update(available=False)
        file = options['json']
        with open(file, 'r') as f:
            for i in pyprind.prog_bar(json.load(f)):
                company = self.getOrCreateCompany(i)
                category = self.getOrCreateCategory(i['category'])
                job = self.getOrCreateJob(company, category, i)
                tags = self.getOrCreateTag(i['tags'], job)
                SkillTag = self.getOrCreateSkillTag(i['skill_tags'], job)

        self.stdout.write(self.style.SUCCESS('insert Json success!!!'))

    @staticmethod
    def getOrCreateCompany(i):
        try:
            obj, created = Company.objects.update_or_create(
                path=i['company']['path'],
                defaults={
                    "brand":i['company']['brand'],
                    "banner":i['company']['banner'],
                    "地址":i['inside']['地址'],
                    "資本額":i['inside'].get('資本額', "未公開"),
                    "公司規模":i['inside'].get('公司規模', '未公開'),
                    "area":i['company']['area'],
                    "description":i['inside']['description'],                    
                }
            )
        except Exception as e:
            print(i)
            raise e
        if created: print(obj)
        return obj

    @staticmethod
    def getOrCreateJob(company, category, i):
        try:
            obj, created = Job.objects.update_or_create(
                path=i['path'],
                defaults={
                    "name":i['name'],
                    "company":company,
                    "intern_tf":i['intern'],
                    "has_salary_info":i['has_salary_info'],
                    "salary":i.get('salary', "未公開"),
                    "avatar":i['company']['banner'],
                    "category":category,
                    "available":True
                }
            )
        except Exception as e:
            print(i['name'], i['path'])
            raise e
        if created: print(obj)
        return obj

    @staticmethod
    def getOrCreateTag(tags, job):
        result = []
        for i in tags:
            obj, created = JobTag.objects.get_or_create(
                name=i['name'],
            )
            if created: print(obj)            
            obj.Job.add(job)
            result.append(obj)
        return result

    @staticmethod
    def getOrCreateCategory(i):
        obj, created = Category.objects.get_or_create(
            name=i['name'],
        )
        if created: print(obj)
        return obj

    @staticmethod
    def getOrCreateSkillTag(skills, job):
        result = []
        for i in skills:
            obj, created = SkillTag.objects.get_or_create(
                name=i['name'],
                defaults={
                    "skill_field":i['skill_field'],
                }
            )
            if created: print(obj)            
            obj.Job.add(job)
            result.append(obj)
        return result
